Actions, Resources, and Condition Keys for Amazon Elastic File System - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon Elastic File System

Amazon Elastic File System (service prefix: `elasticfilesystem` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Elastic File System
- Resource Types Defined by Amazon Elastic File System
- Condition Keys for Amazon Elastic File System

## Actions Defined by Amazon Elastic File System

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
Backup [permission only] | Starts a backup job for an existing file system. | Write | file-system* |  |
CreateFileSystem | Creates a new, empty file system. | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateMountTarget | Creates a mount target for a file system. | Write | file-system* |  |
CreateTags | Creates or overwrites tags associated with a file system. | Tagging | file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteFileSystem | Deletes a file system, permanently severing access to its contents. | Write | file-system* |  |
DeleteMountTarget | Deletes the specified mount target. | Write | file-system* |  |
DeleteTags | Deletes the specified tags from a file system. | Tagging | file-system* |  |
| aws:TagKeys |
DescribeFileSystems | Returns the description of a specific Amazon EFS file system if either the file system CreationToken or the FileSystemId is provided; otherwise, returns descriptions of all file systems owned by the caller's AWS account in the AWS region of the endpoint that you're calling. | List | file-system |  |
DescribeLifecycleConfiguration | Returns the current LifecycleConfiguration object for the specified Amazon EFS file system. | Read | file-system* |  |
DescribeMountTargetSecurityGroups | Returns the security groups currently in effect for a mount target. | Read | file-system* |  |
DescribeMountTargets | Returns the descriptions of all the current mount targets, or a specific mount target, for a file system. | Read | file-system* |  |
DescribeTags | Returns the tags associated with a file system. | Read | file-system* |  |
ModifyMountTargetSecurityGroups | Modifies the set of security groups in effect for a mount target. | Write | file-system* |  |
PutLifecycleConfiguration | Enables lifecycle management by creating a new LifecycleConfiguration object. | Write | file-system* |  |
Restore [permission only] | Starts a restore job for an existing file system. | Write | file-system* |  |
UpdateFileSystem | Updates the throughput mode or the amount of provisioned throughput of an existing file system. | Write | file-system* |  |

## Resource Types Defined by Amazon Elastic File System

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
file-system | `arn:$ { Partition}:elasticfilesystem:$ { Region}:$ { Account}:file-system/$ { FileSystemId}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon Elastic File System

Amazon Elastic File System defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} |  | String
aws:ResourceTag/$ { TagKey} |  | String
aws:TagKeys |  | String